from typing import Any
from .core import MagiDict
from typing import Any

def enchant(d: dict) -> MagiDict: ...
def magi_load(fp: Any, **kwargs: Any) -> MagiDict: ...
def magi_loads(s: str, **kwargs: Any) -> MagiDict: ...
def none(obj: Any) -> Any: ...